@@ -1,7 +1,6 @@
-# -*- coding: utf-8 -*-
 """
 meta attributes for packaging which does not import any dependencies
 """
-__version__ = '3.3.1'
-__author__ = u'python-ldap project'
+__version__ = '3.4.3'
+__author__ = 'python-ldap project'
 __license__ = 'Python style'
